;; Generated package description from gpr-mode.el  -*- no-byte-compile: t -*-
(define-package "gpr-mode" "1.0.1.0.20221221.80047" "Major mode for editing GNAT project files" '((emacs "25.3") (wisi "4.1.1") (gnat-compiler "1.0")) :commit "823df70936ef59237c72a0d626c165b8b9fa53d0" :authors '(("Stephen Leake" . "stephen_leake@member.fsf.org")) :maintainer '("Stephen Leake" . "stephen_leake@member.fsf.org") :url "https://stephe-leake.org/ada/wisitoken.html")
